@@ -7,12 +7,25 @@ set -e -u
 
 # We don't enforce this on Ubuntu, which has less minority architectures.
 if dpkg-vendor --derives-from Ubuntu; then
-	exit 0
+	# Only get out of jail free on the primary archive buildds
+	# Do the RAM check for PPA builds
+	if grep -q '^Purpose: *PRIMARY' /CurrentlyBuilding; then
+		exit 0
+	fi
 fi
 
 # Memory we will require on 32-bit archs
+# This estimate is on the low side, we'll be spilling over into swap, but
+# should still be able to build within a couple of days.
 REQ_32_MEM=1400
 
+# x86 has JIT enabled (which will need more) and machines with >= 4GB of RAM
+# aren't rare, so let's be a little more conservative (c.f. #713787)
+# (except kfreebsd-amd64 which currently has 3GB buildds, sigh)
+if dpkg-architecture -iany-i386 || dpkg-architecture -ilinux-amd64; then
+	REQ_32_MEM=2000
+fi
+
 MEM=$(sed -rne 's/^MemTotal: *([0-9]+) kB$$/\1/p' /proc/meminfo)
 MEM=$((MEM / 1024))
 SWAP=$(sed -rne 's/^SwapTotal: *([0-9]+) kB$$/\1/p' /proc/meminfo)
@@ -36,7 +49,7 @@ fi
 if [ $REQ_MEM -lt $MEM ]; then
 	echo "Assuming we have enough RAM to build."
 else
-	echo "You don't have enough RAM to build PyPy." >&2
+	echo "You probably don't have enough RAM to build PyPy in any reasonable amount of time." >&2
 	echo "Aborting" >&2
 	exit 1
 fi
