@@ -39,7 +39,8 @@ while [ $# -ge 1 ]; do
 	shift
 done
 
-OPTIONS="--batch --source"
+RPYOPTS="--batch --source"
+TARGETOPTS=""
 
 OPT=3
 ROOTFINDER=shadowstack
@@ -50,26 +51,37 @@ elif [ $SANDBOX -gt 0 ]; then
 elif dpkg-architecture -iany-i386; then
 	OPT=jit
 	ROOTFINDER=asmgcc
-	#OPTIONS="$OPTIONS --jit-backend=x86-without-sse2"
-elif dpkg-architecture -iany-armel \
-     || dpkg-architecture -iany-armhf; then
-	# Still in alpha
-	#OPT=jit
+	#RPYOPTS="$RPYOPTS --jit-backend=x86-without-sse2"
+elif dpkg-architecture -iany-arm; then
+	# No JIT support for ARMv5
+	if ! dpkg-architecture -elinux-armel; then
+		OPT=jit
+	fi
 	ROOTFINDER=shadowstack
 elif dpkg-architecture -iany-amd64; then
 	OPT=jit
 	ROOTFINDER=asmgcc
 fi
-OPTIONS="$OPTIONS --opt=$OPT"
+RPYOPTS="$RPYOPTS --opt=$OPT"
 
 if [ $SANDBOX -gt 0 ]; then
-	OPTIONS="$OPTIONS --sandbox --gc=generation"
+	RPYOPTS="$RPYOPTS --sandbox --gc=generation"
 	ROOTFINDER=shadowstack
 fi
 if [ $OPT = "mem" -o $OPT = "jit" -o $OPT = 2 -o $OPT = 3 ]; then
-	OPTIONS="$OPTIONS --gcrootfinder=$ROOTFINDER"
+	RPYOPTS="$RPYOPTS --gcrootfinder=$ROOTFINDER"
+fi
+
+CONTINUATION=0
+if dpkg-architecture -iany-i386 \
+   || dpkg-architecture -iany-amd64 \
+   || dpkg-architecture -iany-arm; then
+	CONTINUATION=1
+fi
+if [ $CONTINUATION -eq 0 ]; then
+	TARGETOPTS="$TARGETOPTS --withoutmod-_continuation"
 fi
 
 set -x
 cd pypy/goal
-exec "$PYTHON" -u ../../rpython/bin/rpython $OPTIONS targetpypystandalone 2>&1
+exec "$PYTHON" -u ../../rpython/bin/rpython $RPYOPTS targetpypystandalone $TARGETOPTS 2>&1
